# SQL Algorithms

!!! tip inline end "SQL Algorithms"
    One of the main benefit of SQL Algorithms is that the 'heavy lifting' is all done on the SQL Database, so if you have large datassets this is the place for you.

- **[SQL](overview.md):** SQL queries that provide a wide range of functionality:

    - Outliers
    - Descriptive Stats
    - Correlations
    - and More
**Oulliers**

::: workbench.algorithms.sql.outliers

::: workbench.algorithms.sql.descriptive_stats

::: workbench.algorithms.sql.correlations

## Questions?
<img align="right" src="../../../images/scp.png" width="180">

The SuperCowPowers team is happy to answer any questions you may have about AWS and Workbench. Please contact us at [workbench@supercowpowers.com](mailto:workbench@supercowpowers.com) or on chat us up on [Discord](https://discord.gg/WHAJuz8sw8) 


